import Button from "./Button";
import { AnimatedText } from "./AnimatedText";
import LaunchWaitlistForm from "./LaunchWaitlistForm";
import { useState } from "react";

const Hero = () => {
  const [isLaunchWaitlistOpen, setIsLaunchWaitlistOpen] = useState(false);

  return (
    <div className="relative overflow-hidden bg-white">
      {/* Optimized single gradient background */}
      <div 
        className="absolute inset-0 pointer-events-none"
        style={{
          background: 'linear-gradient(270deg, rgba(59, 130, 246, 0.15), rgba(139, 92, 246, 0.1), rgba(59, 130, 246, 0.2))',
          willChange: 'auto'
        }}
      />
      <div className="max-w-7xl mx-auto pt-16 pb-10 px-4 sm:px-6 lg:px-8">
        <div className="text-center">
          <h1 className="font-jetbrains tracking-tight text-sm text-nt-blue font-semibold mb-4">
            NEUTONAI PLATFORM
          </h1>
          <h2 className="text-3xl sm:text-4xl md:text-5xl lg:text-6xl font-sora font-bold text-nt-navy tracking-tight leading-tight">
            We Know{" "}
            <AnimatedText 
              words={["SEO", "Content", "AI", "Prompts", "Workflows", "Keyword Research"]} 
              interval={2500}
              className="inline-block"
            />
            <br className="hidden sm:inline" />
            <span className="text-transparent bg-clip-text bg-gradient-to-r from-nt-blue to-nt-violet">
              So You Don't Have To
            </span>
          </h2>
          <p className="mt-4 sm:mt-6 max-w-3xl mx-auto text-base sm:text-lg md:text-xl font-sans text-gray-600 leading-relaxed px-2">
            NeutonAI turns your ideas into publish‑ready, SEO‑optimized content—automatically.
            <br className="hidden sm:inline" />
            <span className="sm:hidden"> </span>No prompt engineering needed. No SEO degree required.
          </p>
          <div className="mt-8 flex flex-col sm:flex-row justify-center gap-4">
            <Button
              onClick={() => setIsLaunchWaitlistOpen(true)}
              size="md"
              variant="primary"
              icon={
                <svg
                  xmlns="http://www.w3.org/2000/svg"
                  className="h-5 w-5"
                  viewBox="0 0 20 20"
                  fill="currentColor"
                >
                  <path
                    fillRule="evenodd"
                    d="M10.293 5.293a1 1 0 011.414 0l4 4a1 1 0 010 1.414l-4 4a1 1 0 01-1.414-1.414L12.586 11H5a1 1 0 110-2h7.586l-2.293-2.293a1 1 0 010-1.414z"
                    clipRule="evenodd"
                  />
                </svg>
              }
            >
              Join the Launch Waitlist
            </Button>
            <Button href="/features" size="md" variant="outline">
              See Features
            </Button>
          </div>
        </div>
      </div>

      {/* Hero Image */}
      <div className="relative mt-4 md:mt-8 pb-8 sm:pb-16 md:pb-20">
        <div className="max-w-6xl mx-auto px-2 sm:px-4 lg:px-8">
          <div className="relative shadow-lg sm:shadow-2xl rounded-lg sm:rounded-2xl overflow-hidden border border-gray-200">
            <div className="absolute inset-0 bg-gradient-to-b from-nt-blue/5 to-nt-blue/0 z-10"></div>
            <div className="bg-nt-gray-light p-2 border-b border-gray-200 flex items-center">
              <div className="flex space-x-2">
                <div className="w-3 h-3 rounded-full" style={{backgroundColor: '#ef4444'}}></div>
                <div className="w-3 h-3 rounded-full" style={{backgroundColor: '#eab308'}}></div>
                <div className="w-3 h-3 rounded-full" style={{backgroundColor: '#22c55e'}}></div>
              </div>
              <div className="mx-auto bg-white rounded-md px-3 py-1 text-sm text-gray-500 flex items-center">
                <span>🔒 dashboard</span>
              </div>
            </div>
            <div className="bg-white overflow-hidden max-h-[250px] sm:max-h-[350px] md:max-h-[550px]">
              <picture>
                <source 
                  srcSet="/images/seo-content-generator-homepage-neutonai-07.webp" 
                  type="image/webp"
                  sizes="(max-width: 768px) 90vw, 80vw"
                  media="(min-width: 768px)"
                />
                <source 
                  srcSet="/images/seo-content-generator-homepage-neutonai-07-mo.webp" 
                  type="image/webp"
                  sizes="100vw"
                  media="(max-width: 767px)"
                />
                <img 
                  src="/images/seo-content-generator-homepage-neutonai-07.webp" 
                  alt="NeutonAI Dashboard - Content creation workflow manager showing SEO tools, AI content writer, and content library with automated workflow options" 
                  className="w-full h-auto object-cover object-center"
                  width="1200"
                  height="600"
                  loading="eager"
                  style={{ objectPosition: 'center 25%' }}
                  decoding="async"
                  sizes="(max-width: 640px) 100vw, (max-width: 768px) 90vw, 80vw"
                />
              </picture>
            </div>
          </div>
        </div>
      </div>
      
      {/* Trusted By Section - Hidden for now, will use later */}
      {/* <div className="max-w-7xl mx-auto mt-16 px-4 sm:px-6 lg:px-8">
        <div className="text-center">
          <p className="text-sm font-medium text-gray-500 uppercase tracking-wider">
            TRUSTED BY FORWARD-THINKING TEAMS
          </p>
          <div className="mt-8 flex flex-wrap justify-center gap-x-12 gap-y-6 opacity-70">
            <div className="h-8 text-gray-400">Company Logo 1</div>
            <div className="h-8 text-gray-400">Company Logo 2</div>
            <div className="h-8 text-gray-400">Company Logo 3</div>
            <div className="h-8 text-gray-400">Company Logo 4</div>
            <div className="h-8 text-gray-400">Company Logo 5</div>
          </div>
        </div>
      </div> */}
      
      {/* Launch Waitlist Modal */}
      <LaunchWaitlistForm 
        isOpen={isLaunchWaitlistOpen} 
        onClose={() => setIsLaunchWaitlistOpen(false)} 
      />
    </div>
  );
};

export default Hero;
